.. _controls_params:

Available model parameters
**************************

In the following, the list of all parameters that are recognized
by BASTA is listed, which is extracted from the :meth:`constants.parameters`
class.

**Please note** that these might not be available/present in the grid,
and there might also be parameters available in the grid that are not
listed here. If these are added to the list in the :meth:`module <constants.parameters>`,
these can also be fitted using BASTA.

.. _controls_params_classic:

Classical parameters
====================

.. csv-table:: Model parameters available in BASTA
    :file: ../docs/param_classic.csv
    :delim: |
    :header-rows: 1


.. _controls_params_filters:

Synthetic magnitudes
====================

.. csv-table:: Magnitudes for given filters
    :file: ../docs/param_filters.csv
    :delim: |
    :header-rows: 1
